Crate mpl_bubblegum

Crate mpl_bubblegum 

Modules

accounts
This code was AUTOGENERATED using the kinobi library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun kinobi to update it.
errors
This code was AUTOGENERATED using the kinobi library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun kinobi to update it.
hash
instructions
This code was AUTOGENERATED using the kinobi library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun kinobi to update it.
programs
This code was AUTOGENERATED using the kinobi library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun kinobi to update it.
types
This code was AUTOGENERATED using the kinobi library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun kinobi to update it.
utils

Structs

Flags
Bitfield representation of asset flags.
LeafSchemaEvent

Enums

InstructionName

Constants

DEFAULT_FLAGS
Default flags for LeafSchemaV2.
ID
mpl_bubblegum program ID.

Functions

get_instruction_type