pub struct CreateTreeConfigCpiBuilder<'a, 'b> { /* private fields */ }Expand description
create_tree_config CPI instruction builder.
Implementations
Sourceimpl<'a, 'b> CreateTreeConfigCpiBuilder<'a, 'b>
impl<'a, 'b> CreateTreeConfigCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn tree_config(&mut self, tree_config: &'b AccountInfo<'a>) -> &mut Self
pub fn merkle_tree(&mut self, merkle_tree: &'b AccountInfo<'a>) -> &mut Self
pub fn payer(&mut self, payer: &'b AccountInfo<'a>) -> &mut Self
pub fn tree_creator(&mut self, tree_creator: &'b AccountInfo<'a>) -> &mut Self
pub fn log_wrapper(&mut self, log_wrapper: &'b AccountInfo<'a>) -> &mut Self
pub fn compression_program( &mut self, compression_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn max_depth(&mut self, max_depth: u32) -> &mut Self
pub fn max_buffer_size(&mut self, max_buffer_size: u32) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult