pub struct CreateTreeConfigInstructionArgs {
pub max_depth: u32,
pub max_buffer_size: u32,
pub public: Option<bool>,
}Fields
max_depth: u32max_buffer_size: u32public: Option<bool>Trait Implementations
Sourceimpl BorshDeserialize for CreateTreeConfigInstructionArgs
impl BorshDeserialize for CreateTreeConfigInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateTreeConfigInstructionArgs
impl Clone for CreateTreeConfigInstructionArgs
Sourcefn clone(&self) -> CreateTreeConfigInstructionArgs
fn clone(&self) -> CreateTreeConfigInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CreateTreeConfigInstructionArgs
impl PartialEq for CreateTreeConfigInstructionArgs
Sourcefn eq(&self, other: &CreateTreeConfigInstructionArgs) -> bool
fn eq(&self, other: &CreateTreeConfigInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CreateTreeConfigInstructionArgs
impl StructuralPartialEq for CreateTreeConfigInstructionArgs