pub struct SetAndVerifyCollection {Show 16 fields
pub tree_config: Pubkey,
pub leaf_owner: Pubkey,
pub leaf_delegate: Pubkey,
pub merkle_tree: Pubkey,
pub payer: Pubkey,
pub tree_creator_or_delegate: (Pubkey, bool),
pub collection_authority: Pubkey,
pub collection_authority_record_pda: Option<Pubkey>,
pub collection_mint: Pubkey,
pub collection_metadata: Pubkey,
pub collection_edition: Pubkey,
pub bubblegum_signer: Pubkey,
pub log_wrapper: Pubkey,
pub compression_program: Pubkey,
pub token_metadata_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Accounts.
Fields
tree_config: Pubkeyleaf_owner: Pubkeyleaf_delegate: Pubkeymerkle_tree: Pubkeypayer: Pubkeytree_creator_or_delegate: (Pubkey, bool)This account is checked to be a signer in
the case of set_and_verify_collection where
we are actually changing the NFT metadata.
If there is no collecton authority record PDA then this must be the Bubblegum program address.
collection_mint: Pubkeycollection_metadata: Pubkeycollection_edition: Pubkeybubblegum_signer: Pubkeylog_wrapper: Pubkeycompression_program: Pubkeytoken_metadata_program: Pubkeysystem_program: PubkeyImplementations
Sourceimpl SetAndVerifyCollection
impl SetAndVerifyCollection
pub fn instruction( &self, args: SetAndVerifyCollectionInstructionArgs, ) -> Instruction
pub fn instruction_with_remaining_accounts( &self, args: SetAndVerifyCollectionInstructionArgs, remaining_accounts: &[AccountMeta], ) -> Instruction