SetAndVerifyCollectionBuilder

Struct SetAndVerifyCollectionBuilder 

pub struct SetAndVerifyCollectionBuilder { /* private fields */ }
Instruction builder.

Implementations

Source

impl SetAndVerifyCollectionBuilder

pub fn new() -> Self

pub fn tree_config(&mut self, tree_config: Pubkey) -> &mut Self

pub fn leaf_owner(&mut self, leaf_owner: Pubkey) -> &mut Self

pub fn leaf_delegate(&mut self, leaf_delegate: Pubkey) -> &mut Self

pub fn merkle_tree(&mut self, merkle_tree: Pubkey) -> &mut Self

pub fn payer(&mut self, payer: Pubkey) -> &mut Self

pub fn tree_creator_or_delegate( &mut self, tree_creator_or_delegate: Pubkey, as_signer: bool, ) -> &mut Self

This account is checked to be a signer in the case of set_and_verify_collection where we are actually changing the NFT metadata.

pub fn collection_authority( &mut self, collection_authority: Pubkey, ) -> &mut Self

pub fn collection_authority_record_pda( &mut self, collection_authority_record_pda: Option<Pubkey>, ) -> &mut Self

[optional account] If there is no collecton authority record PDA then this must be the Bubblegum program address.

pub fn collection_mint(&mut self, collection_mint: Pubkey) -> &mut Self

pub fn collection_metadata(&mut self, collection_metadata: Pubkey) -> &mut Self

pub fn collection_edition(&mut self, collection_edition: Pubkey) -> &mut Self

pub fn bubblegum_signer(&mut self, bubblegum_signer: Pubkey) -> &mut Self

[optional account, default to 'BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY']

pub fn log_wrapper(&mut self, log_wrapper: Pubkey) -> &mut Self

[optional account, default to 'noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV']

pub fn compression_program(&mut self, compression_program: Pubkey) -> &mut Self

[optional account, default to 'cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK']

pub fn token_metadata_program( &mut self, token_metadata_program: Pubkey, ) -> &mut Self

[optional account, default to 'BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY']

pub fn system_program(&mut self, system_program: Pubkey) -> &mut Self

[optional account, default to '11111111111111111111111111111111']

pub fn root(&mut self, root: [u8; 32]) -> &mut Self

pub fn data_hash(&mut self, data_hash: [u8; 32]) -> &mut Self

pub fn creator_hash(&mut self, creator_hash: [u8; 32]) -> &mut Self

pub fn nonce(&mut self, nonce: u64) -> &mut Self

pub fn index(&mut self, index: u32) -> &mut Self

pub fn metadata(&mut self, metadata: MetadataArgs) -> &mut Self

pub fn collection(&mut self, collection: Pubkey) -> &mut Self

pub fn add_remaining_account(&mut self, account: AccountMeta) -> &mut Self

Add an aditional account to the instruction.

pub fn add_remaining_accounts(&mut self, accounts: &[AccountMeta]) -> &mut Self

Add additional accounts to the instruction.

pub fn instruction(&self) -> Instruction