SetCollectionV2

Struct SetCollectionV2 

pub struct SetCollectionV2 {
Show 14 fields pub tree_config: Pubkey, pub payer: Pubkey, pub authority: Option<Pubkey>, pub new_collection_authority: Option<Pubkey>, pub leaf_owner: Pubkey, pub leaf_delegate: Option<Pubkey>, pub merkle_tree: Pubkey, pub core_collection: Option<Pubkey>, pub new_core_collection: Option<Pubkey>, pub mpl_core_cpi_signer: Pubkey, pub log_wrapper: Pubkey, pub compression_program: Pubkey, pub mpl_core_program: Pubkey, pub system_program: Pubkey,
}
Accounts.

Fields

tree_config: Pubkeypayer: Pubkeyauthority: Option<Pubkey>

If item is not in a collection, then authority must be tree owner/delegate. If item is getting removed from a collection, then this must be an authority for the existing collection. Defaults to payer

new_collection_authority: Option<Pubkey>

If item is getting added to a new collection, then this must be the authority for the new collection. Defaults to authority

leaf_owner: Pubkeyleaf_delegate: Option<Pubkey>

Defaults to leaf_owner

merkle_tree: Pubkeycore_collection: Option<Pubkey>new_core_collection: Option<Pubkey>mpl_core_cpi_signer: Pubkeylog_wrapper: Pubkeycompression_program: Pubkeympl_core_program: Pubkeysystem_program: Pubkey

Implementations