pub struct SetCollectionV2Cpi<'a, 'b> {Show 16 fields
pub __program: &'b AccountInfo<'a>,
pub tree_config: &'b AccountInfo<'a>,
pub payer: &'b AccountInfo<'a>,
pub authority: Option<&'b AccountInfo<'a>>,
pub new_collection_authority: Option<&'b AccountInfo<'a>>,
pub leaf_owner: &'b AccountInfo<'a>,
pub leaf_delegate: Option<&'b AccountInfo<'a>>,
pub merkle_tree: &'b AccountInfo<'a>,
pub core_collection: Option<&'b AccountInfo<'a>>,
pub new_core_collection: Option<&'b AccountInfo<'a>>,
pub mpl_core_cpi_signer: &'b AccountInfo<'a>,
pub log_wrapper: &'b AccountInfo<'a>,
pub compression_program: &'b AccountInfo<'a>,
pub mpl_core_program: &'b AccountInfo<'a>,
pub system_program: &'b AccountInfo<'a>,
pub __args: SetCollectionV2InstructionArgs,
}Expand description
set_collection_v2 CPI instruction.
Fields
__program: &'b AccountInfo<'a>The program to invoke.
tree_config: &'b AccountInfo<'a>payer: &'b AccountInfo<'a>If item is not in a collection, then authority must be tree owner/delegate. If item is
getting removed from a collection, then this must be an authority for the existing
collection. Defaults to payer
If item is getting added to a new collection, then this must be the authority
for the new collection. Defaults to authority
leaf_owner: &'b AccountInfo<'a>leaf_delegate: Option<&'b AccountInfo<'a>>Defaults to leaf_owner
merkle_tree: &'b AccountInfo<'a>core_collection: Option<&'b AccountInfo<'a>>new_core_collection: Option<&'b AccountInfo<'a>>mpl_core_cpi_signer: &'b AccountInfo<'a>log_wrapper: &'b AccountInfo<'a>compression_program: &'b AccountInfo<'a>mpl_core_program: &'b AccountInfo<'a>system_program: &'b AccountInfo<'a>__args: SetCollectionV2InstructionArgsThe arguments for the instruction.
Implementations
Sourceimpl<'a, 'b> SetCollectionV2Cpi<'a, 'b>
impl<'a, 'b> SetCollectionV2Cpi<'a, 'b>
pub fn new( program: &'b AccountInfo<'a>, accounts: SetCollectionV2CpiAccounts<'a, 'b>, args: SetCollectionV2InstructionArgs, ) -> Self
pub fn invoke(&self) -> ProgramResult
pub fn invoke_with_remaining_accounts( &self, remaining_accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult
pub fn invoke_signed_with_remaining_accounts( &self, signers_seeds: &[&[&[u8]]], remaining_accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> ProgramResult