pub struct VerifyCollectionCpi<'a, 'b> {Show 18 fields
pub __program: &'b AccountInfo<'a>,
pub tree_config: &'b AccountInfo<'a>,
pub leaf_owner: &'b AccountInfo<'a>,
pub leaf_delegate: &'b AccountInfo<'a>,
pub merkle_tree: &'b AccountInfo<'a>,
pub payer: &'b AccountInfo<'a>,
pub tree_creator_or_delegate: &'b AccountInfo<'a>,
pub collection_authority: &'b AccountInfo<'a>,
pub collection_authority_record_pda: Option<&'b AccountInfo<'a>>,
pub collection_mint: &'b AccountInfo<'a>,
pub collection_metadata: &'b AccountInfo<'a>,
pub collection_edition: &'b AccountInfo<'a>,
pub bubblegum_signer: &'b AccountInfo<'a>,
pub log_wrapper: &'b AccountInfo<'a>,
pub compression_program: &'b AccountInfo<'a>,
pub token_metadata_program: &'b AccountInfo<'a>,
pub system_program: &'b AccountInfo<'a>,
pub __args: VerifyCollectionInstructionArgs,
}Expand description
verify_collection CPI instruction.
Fields
__program: &'b AccountInfo<'a>The program to invoke.
tree_config: &'b AccountInfo<'a>leaf_owner: &'b AccountInfo<'a>leaf_delegate: &'b AccountInfo<'a>merkle_tree: &'b AccountInfo<'a>payer: &'b AccountInfo<'a>tree_creator_or_delegate: &'b AccountInfo<'a>This account is checked to be a signer in
the case of set_and_verify_collection where
we are actually changing the NFT metadata.
If there is no collecton authority record PDA then this must be the Bubblegum program address.
collection_mint: &'b AccountInfo<'a>collection_metadata: &'b AccountInfo<'a>collection_edition: &'b AccountInfo<'a>bubblegum_signer: &'b AccountInfo<'a>log_wrapper: &'b AccountInfo<'a>compression_program: &'b AccountInfo<'a>token_metadata_program: &'b AccountInfo<'a>system_program: &'b AccountInfo<'a>__args: VerifyCollectionInstructionArgsThe arguments for the instruction.
Implementations
Sourceimpl<'a, 'b> VerifyCollectionCpi<'a, 'b>
impl<'a, 'b> VerifyCollectionCpi<'a, 'b>
pub fn new( program: &'b AccountInfo<'a>, accounts: VerifyCollectionCpiAccounts<'a, 'b>, args: VerifyCollectionInstructionArgs, ) -> Self
pub fn invoke(&self) -> ProgramResult
pub fn invoke_with_remaining_accounts( &self, remaining_accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult
pub fn invoke_signed_with_remaining_accounts( &self, signers_seeds: &[&[&[u8]]], remaining_accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> ProgramResult