pub struct Collection {
pub verified: bool,
pub key: Pubkey,
}Fields
verified: boolkey: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for Collection
impl BorshDeserialize for Collection
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Collection
impl BorshSerialize for Collection
Sourceimpl Clone for Collection
impl Clone for Collection
Sourcefn clone(&self) -> Collection
fn clone(&self) -> Collection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Collection
impl Debug for Collection
Sourceimpl PartialEq for Collection
impl PartialEq for Collection
impl Eq for Collection
impl StructuralPartialEq for Collection