MetadataArgs

Struct MetadataArgs 

pub struct MetadataArgs {
    pub name: String,
    pub symbol: String,
    pub uri: String,
    pub seller_fee_basis_points: u16,
    pub primary_sale_happened: bool,
    pub is_mutable: bool,
    pub edition_nonce: Option<u8>,
    pub token_standard: Option<TokenStandard>,
    pub collection: Option<Collection>,
    pub uses: Option<Uses>,
    pub token_program_version: TokenProgramVersion,
    pub creators: Vec<Creator>,
}

Fields

name: String

The name of the asset

symbol: String

The symbol for the asset

uri: String

URI pointing to JSON representing the asset

seller_fee_basis_points: u16

Royalty basis points that goes to creators in secondary sales (0-10000)

primary_sale_happened: bool

Immutable, once flipped, all sales of this metadata are considered secondary.

is_mutable: bool

Whether or not the data struct is mutable, default is not

edition_nonce: Option<u8>

nonce for easy calculation of editions, if present

token_standard: Option<TokenStandard>

Token standard. Currently only NonFungible is allowed.

collection: Option<Collection>

Collection

uses: Option<Uses>

Uses

token_program_version: TokenProgramVersioncreators: Vec<Creator>