pub enum MplBubblegumError {
Show 57 variants
AssetOwnerMismatch,
PublicKeyMismatch,
HashingMismatch,
UnsupportedSchemaVersion,
CreatorShareTotalMustBe100,
DuplicateCreatorAddress,
CreatorDidNotVerify,
CreatorNotFound,
NoCreatorsPresent,
CreatorHashMismatch,
DataHashMismatch,
CreatorsTooLong,
MetadataNameTooLong,
MetadataSymbolTooLong,
MetadataUriTooLong,
MetadataBasisPointsTooHigh,
TreeAuthorityIncorrect,
InsufficientMintCapacity,
NumericalOverflowError,
IncorrectOwner,
CollectionCannotBeVerifiedInThisInstruction,
CollectionNotFound,
AlreadyVerified,
AlreadyUnverified,
UpdateAuthorityIncorrect,
LeafAuthorityMustSign,
CollectionMustBeSized,
MetadataMintMismatch,
InvalidCollectionAuthority,
InvalidDelegateRecord,
CollectionMasterEditionAccountInvalid,
CollectionMustBeAUniqueMasterEdition,
UnknownExternalError,
DecompressionDisabled,
MissingCollectionMintAccount,
MissingCollectionMetadataAccount,
CollectionMismatch,
MetadataImmutable,
PrimarySaleCanOnlyBeFlippedToTrue,
CreatorDidNotUnverify,
InvalidTokenStandard,
InvalidCanopySize,
InvalidLogWrapper,
InvalidCompressionProgram,
LeafMustBeDelegated,
AssetIsFrozen,
AssetIsNonTransferable,
InvalidAuthority,
CollectionIsFrozen,
CollectionMustHaveBubblegumPlugin,
NotAvailable,
MissingCollectionAccount,
AssetDataLengthTooLong,
AlreadyInCollection,
AlreadyNotInCollection,
MissingMplCoreCpiSignerAccount,
AssetIsNotFrozen,
}Variants
AssetOwnerMismatch
6000 (0x1770) - Asset Owner Does not match
PublicKeyMismatch
6001 (0x1771) - PublicKeyMismatch
HashingMismatch
6002 (0x1772) - Hashing Mismatch Within Leaf Schema
UnsupportedSchemaVersion
6003 (0x1773) - Unsupported Schema Version
6004 (0x1774) - Creator shares must sum to 100
DuplicateCreatorAddress
6005 (0x1775) - No duplicate creator addresses in metadata
CreatorDidNotVerify
6006 (0x1776) - Creator did not verify the metadata
CreatorNotFound
6007 (0x1777) - Creator not found in creator Vec
NoCreatorsPresent
6008 (0x1778) - No creators in creator Vec
CreatorHashMismatch
6009 (0x1779) - User-provided creator Vec must result in same user-provided creator hash
DataHashMismatch
6010 (0x177A) - User-provided metadata must result in same user-provided data hash
CreatorsTooLong
6011 (0x177B) - Creators list too long
MetadataNameTooLong
6012 (0x177C) - Name in metadata is too long
MetadataSymbolTooLong
6013 (0x177D) - Symbol in metadata is too long
MetadataUriTooLong
6014 (0x177E) - Uri in metadata is too long
MetadataBasisPointsTooHigh
6015 (0x177F) - Basis points in metadata cannot exceed 10000
TreeAuthorityIncorrect
6016 (0x1780) - Tree creator or tree delegate must sign.
InsufficientMintCapacity
6017 (0x1781) - Not enough unapproved mints left
NumericalOverflowError
6018 (0x1782) - NumericalOverflowError
IncorrectOwner
6019 (0x1783) - Incorrect account owner
CollectionCannotBeVerifiedInThisInstruction
6020 (0x1784) - Cannot Verify Collection in this Instruction
CollectionNotFound
6021 (0x1785) - Collection Not Found on Metadata
AlreadyVerified
6022 (0x1786) - Collection item is already verified.
AlreadyUnverified
6023 (0x1787) - Collection item is already unverified.
UpdateAuthorityIncorrect
6024 (0x1788) - Incorrect leaf metadata update authority.
LeafAuthorityMustSign
6025 (0x1789) - This transaction must be signed by either the leaf owner or leaf delegate
CollectionMustBeSized
6026 (0x178A) - Collection Not Compatable with Compression, Must be Sized
MetadataMintMismatch
6027 (0x178B) - Metadata mint does not match collection mint
InvalidCollectionAuthority
6028 (0x178C) - Invalid collection authority
InvalidDelegateRecord
6029 (0x178D) - Invalid delegate record pda derivation
CollectionMasterEditionAccountInvalid
6030 (0x178E) - Edition account doesnt match collection
CollectionMustBeAUniqueMasterEdition
6031 (0x178F) - Collection Must Be a Unique Master Edition v2
UnknownExternalError
6032 (0x1790) - Could not convert external error to BubblegumError
DecompressionDisabled
6033 (0x1791) - Decompression is disabled for this tree.
MissingCollectionMintAccount
6034 (0x1792) - Missing collection mint account
MissingCollectionMetadataAccount
6035 (0x1793) - Missing collection metadata account
CollectionMismatch
6036 (0x1794) - Collection mismatch
MetadataImmutable
6037 (0x1795) - Metadata not mutable
PrimarySaleCanOnlyBeFlippedToTrue
6038 (0x1796) - Can only update primary sale to true
CreatorDidNotUnverify
6039 (0x1797) - Creator did not unverify the metadata
InvalidTokenStandard
6040 (0x1798) - Only NonFungible standard is supported
InvalidCanopySize
6041 (0x1799) - Canopy size should be set bigger for this tree
InvalidLogWrapper
6042 (0x179A) - Invalid log wrapper program
InvalidCompressionProgram
6043 (0x179B) - Invalid compression program
LeafMustBeDelegated
6044 (0x179C) - Leaf must be delegated to someone other than the leaf owner
AssetIsFrozen
6045 (0x179D) - Asset is frozen
AssetIsNonTransferable
6046 (0x179E) - Asset is non-transferable
InvalidAuthority
6047 (0x179F) - Invalid authority
CollectionIsFrozen
6048 (0x17A0) - Collection is frozen
CollectionMustHaveBubblegumPlugin
6049 (0x17A1) - Core collections must have the Bubblegum V2 plugin on them
NotAvailable
6050 (0x17A2) - Feature not currently available
MissingCollectionAccount
6051 (0x17A3) - Missing collection account
AssetDataLengthTooLong
6052 (0x17A4) - Asset data length too long
AlreadyInCollection
6053 (0x17A5) - Item is already in the collection
AlreadyNotInCollection
6054 (0x17A6) - Item is already not in a collection
MissingMplCoreCpiSignerAccount
6055 (0x17A7) - Missing mpl-core CPI signer account
AssetIsNotFrozen
6056 (0x17A8) - Asset is not frozen