pub struct SetCollectionV2Builder { /* private fields */ }Expand description
Instruction builder.
Implementations
Sourceimpl SetCollectionV2Builder
impl SetCollectionV2Builder
pub fn new() -> Self
pub fn tree_config(&mut self, tree_config: Pubkey) -> &mut Self
pub fn payer(&mut self, payer: Pubkey) -> &mut Self
[optional account]
If item is not in a collection, then authority must be tree owner/delegate. If item is
getting removed from a collection, then this must be an authority for the existing
collection. Defaults to payer
[optional account]
If item is getting added to a new collection, then this must be the authority
for the new collection. Defaults to authority
pub fn leaf_owner(&mut self, leaf_owner: Pubkey) -> &mut Self
Sourcepub fn leaf_delegate(&mut self, leaf_delegate: Option<Pubkey>) -> &mut Self
pub fn leaf_delegate(&mut self, leaf_delegate: Option<Pubkey>) -> &mut Self
[optional account]
Defaults to leaf_owner
pub fn merkle_tree(&mut self, merkle_tree: Pubkey) -> &mut Self
Sourcepub fn core_collection(&mut self, core_collection: Option<Pubkey>) -> &mut Self
pub fn core_collection(&mut self, core_collection: Option<Pubkey>) -> &mut Self
[optional account]
Sourcepub fn new_core_collection(
&mut self,
new_core_collection: Option<Pubkey>,
) -> &mut Self
pub fn new_core_collection( &mut self, new_core_collection: Option<Pubkey>, ) -> &mut Self
[optional account]
Sourcepub fn mpl_core_cpi_signer(&mut self, mpl_core_cpi_signer: Pubkey) -> &mut Self
pub fn mpl_core_cpi_signer(&mut self, mpl_core_cpi_signer: Pubkey) -> &mut Self
[optional account, default to 'CbNY3JiXdXNE9tPNEk1aRZVEkWdj2v7kfJLNQwZZgpXk']
Sourcepub fn log_wrapper(&mut self, log_wrapper: Pubkey) -> &mut Self
pub fn log_wrapper(&mut self, log_wrapper: Pubkey) -> &mut Self
[optional account, default to 'mnoopTCrg4p8ry25e4bcWA9XZjbNjMTfgYVGGEdRsf3']
Sourcepub fn compression_program(&mut self, compression_program: Pubkey) -> &mut Self
pub fn compression_program(&mut self, compression_program: Pubkey) -> &mut Self
[optional account, default to 'mcmt6YrQEMKw8Mw43FmpRLmf7BqRnFMKmAcbxE3xkAW']
Sourcepub fn mpl_core_program(&mut self, mpl_core_program: Pubkey) -> &mut Self
pub fn mpl_core_program(&mut self, mpl_core_program: Pubkey) -> &mut Self
[optional account, default to 'CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d']
Sourcepub fn system_program(&mut self, system_program: Pubkey) -> &mut Self
pub fn system_program(&mut self, system_program: Pubkey) -> &mut Self
[optional account, default to '11111111111111111111111111111111']
pub fn root(&mut self, root: [u8; 32]) -> &mut Self
Sourcepub fn asset_data_hash(&mut self, asset_data_hash: [u8; 32]) -> &mut Self
pub fn asset_data_hash(&mut self, asset_data_hash: [u8; 32]) -> &mut Self
[optional argument]
pub fn nonce(&mut self, nonce: u64) -> &mut Self
pub fn index(&mut self, index: u32) -> &mut Self
pub fn metadata(&mut self, metadata: MetadataArgsV2) -> &mut Self
Sourcepub fn add_remaining_account(&mut self, account: AccountMeta) -> &mut Self
pub fn add_remaining_account(&mut self, account: AccountMeta) -> &mut Self
Add an aditional account to the instruction.
Sourcepub fn add_remaining_accounts(&mut self, accounts: &[AccountMeta]) -> &mut Self
pub fn add_remaining_accounts(&mut self, accounts: &[AccountMeta]) -> &mut Self
Add additional accounts to the instruction.