pub struct MetadataArgs {
pub name: String,
pub symbol: String,
pub uri: String,
pub seller_fee_basis_points: u16,
pub primary_sale_happened: bool,
pub is_mutable: bool,
pub edition_nonce: Option<u8>,
pub token_standard: Option<TokenStandard>,
pub collection: Option<Collection>,
pub uses: Option<Uses>,
pub token_program_version: TokenProgramVersion,
pub creators: Vec<Creator>,
}Fields
name: StringThe name of the asset
symbol: StringThe symbol for the asset
uri: StringURI pointing to JSON representing the asset
seller_fee_basis_points: u16Royalty basis points that goes to creators in secondary sales (0-10000)
primary_sale_happened: boolImmutable, once flipped, all sales of this metadata are considered secondary.
is_mutable: boolWhether or not the data struct is mutable, default is not
edition_nonce: Option<u8>nonce for easy calculation of editions, if present
token_standard: Option<TokenStandard>Token standard. Currently only NonFungible is allowed.
collection: Option<Collection>Collection
uses: Option<Uses>Uses
token_program_version: TokenProgramVersioncreators: Vec<Creator>Trait Implementations
Sourceimpl BorshDeserialize for MetadataArgs
impl BorshDeserialize for MetadataArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MetadataArgs
impl BorshSerialize for MetadataArgs
Sourceimpl Clone for MetadataArgs
impl Clone for MetadataArgs
Sourcefn clone(&self) -> MetadataArgs
fn clone(&self) -> MetadataArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetadataArgs
impl Debug for MetadataArgs
Sourceimpl From<MetadataArgsV2> for MetadataArgs
MetadataArgs
Differences:
edition_nonce not present in V2, default to None
collection is always considered verified in V2
uses not present in V2, default to None
token_program_version not present in V2, default to TokenProgramVersion::Original
impl From<MetadataArgsV2> for MetadataArgs
MetadataArgs
Differences:
edition_nonce not present in V2, default to None
collection is always considered verified in V2
uses not present in V2, default to None
token_program_version not present in V2, default to TokenProgramVersion::Original
Sourcefn from(v2: MetadataArgsV2) -> Self
fn from(v2: MetadataArgsV2) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for MetadataArgs
impl PartialEq for MetadataArgs
impl Eq for MetadataArgs
impl StructuralPartialEq for MetadataArgs